==> pmml-model-1.0.9-sources.jar: org/dmg/pmml/UnivariateStats.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Counts" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}NumericInfo" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}DiscrStats" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}ContStats" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Anova" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="field" type="{http://www.dmg.org/PMML-4_1}FIELD-NAME" />
 *       &lt;attribute name="weighted" default="0">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;enumeration value="0"/>
 *             &lt;enumeration value="1"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "counts",
    "numericInfo",
    "discrStats",
    "contStats",
    "anova"
})
@XmlRootElement(name = "UnivariateStats")
public class UnivariateStats
    extends PMMLObject
    implements Locatable, Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "Counts")
    protected Counts counts;
    @XmlElement(name = "NumericInfo")
    protected NumericInfo numericInfo;
    @XmlElement(name = "DiscrStats")
    protected DiscrStats discrStats;
    @XmlElement(name = "ContStats")
    protected ContStats contStats;
    @XmlElement(name = "Anova")
    protected Anova anova;
    @XmlAttribute(name = "field")
    protected FieldName field;
    @XmlAttribute(name = "weighted")
    protected String weighted;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the counts property.
     * 
     * @return
     *     possible object is
     *     {@link Counts }
     *     
     */
    public Counts getCounts() {
        return counts;
    }

    /**
     * Sets the value of the counts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Counts }
     *     
     */
    public void setCounts(Counts value) {
        this.counts = value;
    }

    /**
     * Gets the value of the numericInfo property.
     * 
     * @return
     *     possible object is
     *     {@link NumericInfo }
     *     
     */
    public NumericInfo getNumericInfo() {
        return numericInfo;
    }

    /**
     * Sets the value of the numericInfo property.
     * 
     * @param value
     *     allowed object is
     *     {@link NumericInfo }
     *     
     */
    public void setNumericInfo(NumericInfo value) {
        this.numericInfo = value;
    }

    /**
     * Gets the value of the discrStats property.
     * 
     * @return
     *     possible object is
     *     {@link DiscrStats }
     *     
     */
    public DiscrStats getDiscrStats() {
        return discrStats;
    }

    /**
     * Sets the value of the discrStats property.
     * 
     * @param value
     *     allowed object is
     *     {@link DiscrStats }
     *     
     */
    public void setDiscrStats(DiscrStats value) {
        this.discrStats = value;
    }

    /**
     * Gets the value of the contStats property.
     * 
     * @return
     *     possible object is
     *     {@link ContStats }
     *     
     */
    public ContStats getContStats() {
        return contStats;
    }

    /**
     * Sets the value of the contStats property.
     * 
     * @param value
     *     allowed object is
     *     {@link ContStats }
     *     
     */
    public void setContStats(ContStats value) {
        this.contStats = value;
    }

    /**
     * Gets the value of the anova property.
     * 
     * @return
     *     possible object is
     *     {@link Anova }
     *     
     */
    public Anova getAnova() {
        return anova;
    }

    /**
     * Sets the value of the anova property.
     * 
     * @param value
     *     allowed object is
     *     {@link Anova }
     *     
     */
    public void setAnova(Anova value) {
        this.anova = value;
    }

    /**
     * Gets the value of the field property.
     * 
     * @return
     *     possible object is
     *     {@link FieldName }
     *     
     */
    public FieldName getField() {
        return field;
    }

    /**
     * Sets the value of the field property.
     * 
     * @param value
     *     allowed object is
     *     {@link FieldName }
     *     
     */
    public void setField(FieldName value) {
        this.field = value;
    }

    /**
     * Gets the value of the weighted property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWeighted() {
        if (weighted == null) {
            return "0";
        } else {
            return weighted;
        }
    }

    /**
     * Sets the value of the weighted property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWeighted(String value) {
        this.weighted = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof UnivariateStats)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final UnivariateStats that = ((UnivariateStats) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            Counts lhsCounts;
            lhsCounts = this.getCounts();
            Counts rhsCounts;
            rhsCounts = that.getCounts();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "counts", lhsCounts), LocatorUtils.property(thatLocator, "counts", rhsCounts), lhsCounts, rhsCounts)) {
                return false;
            }
        }
        {
            NumericInfo lhsNumericInfo;
            lhsNumericInfo = this.getNumericInfo();
            NumericInfo rhsNumericInfo;
            rhsNumericInfo = that.getNumericInfo();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numericInfo", lhsNumericInfo), LocatorUtils.property(thatLocator, "numericInfo", rhsNumericInfo), lhsNumericInfo, rhsNumericInfo)) {
                return false;
            }
        }
        {
            DiscrStats lhsDiscrStats;
            lhsDiscrStats = this.getDiscrStats();
            DiscrStats rhsDiscrStats;
            rhsDiscrStats = that.getDiscrStats();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "discrStats", lhsDiscrStats), LocatorUtils.property(thatLocator, "discrStats", rhsDiscrStats), lhsDiscrStats, rhsDiscrStats)) {
                return false;
            }
        }
        {
            ContStats lhsContStats;
            lhsContStats = this.getContStats();
            ContStats rhsContStats;
            rhsContStats = that.getContStats();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "contStats", lhsContStats), LocatorUtils.property(thatLocator, "contStats", rhsContStats), lhsContStats, rhsContStats)) {
                return false;
            }
        }
        {
            Anova lhsAnova;
            lhsAnova = this.getAnova();
            Anova rhsAnova;
            rhsAnova = that.getAnova();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "anova", lhsAnova), LocatorUtils.property(thatLocator, "anova", rhsAnova), lhsAnova, rhsAnova)) {
                return false;
            }
        }
        {
            FieldName lhsField;
            lhsField = this.getField();
            FieldName rhsField;
            rhsField = that.getField();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "field", lhsField), LocatorUtils.property(thatLocator, "field", rhsField), lhsField, rhsField)) {
                return false;
            }
        }
        {
            String lhsWeighted;
            lhsWeighted = this.getWeighted();
            String rhsWeighted;
            rhsWeighted = that.getWeighted();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "weighted", lhsWeighted), LocatorUtils.property(thatLocator, "weighted", rhsWeighted), lhsWeighted, rhsWeighted)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            Counts theCounts;
            theCounts = this.getCounts();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "counts", theCounts), currentHashCode, theCounts);
        }
        {
            NumericInfo theNumericInfo;
            theNumericInfo = this.getNumericInfo();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numericInfo", theNumericInfo), currentHashCode, theNumericInfo);
        }
        {
            DiscrStats theDiscrStats;
            theDiscrStats = this.getDiscrStats();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "discrStats", theDiscrStats), currentHashCode, theDiscrStats);
        }
        {
            ContStats theContStats;
            theContStats = this.getContStats();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "contStats", theContStats), currentHashCode, theContStats);
        }
        {
            Anova theAnova;
            theAnova = this.getAnova();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "anova", theAnova), currentHashCode, theAnova);
        }
        {
            FieldName theField;
            theField = this.getField();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "field", theField), currentHashCode, theField);
        }
        {
            String theWeighted;
            theWeighted = this.getWeighted();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "weighted", theWeighted), currentHashCode, theWeighted);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            Counts theCounts;
            theCounts = this.getCounts();
            strategy.appendField(locator, this, "counts", buffer, theCounts);
        }
        {
            NumericInfo theNumericInfo;
            theNumericInfo = this.getNumericInfo();
            strategy.appendField(locator, this, "numericInfo", buffer, theNumericInfo);
        }
        {
            DiscrStats theDiscrStats;
            theDiscrStats = this.getDiscrStats();
            strategy.appendField(locator, this, "discrStats", buffer, theDiscrStats);
        }
        {
            ContStats theContStats;
            theContStats = this.getContStats();
            strategy.appendField(locator, this, "contStats", buffer, theContStats);
        }
        {
            Anova theAnova;
            theAnova = this.getAnova();
            strategy.appendField(locator, this, "anova", buffer, theAnova);
        }
        {
            FieldName theField;
            theField = this.getField();
            strategy.appendField(locator, this, "field", buffer, theField);
        }
        {
            String theWeighted;
            theWeighted = this.getWeighted();
            strategy.appendField(locator, this, "weighted", buffer, theWeighted);
        }
        return buffer;
    }

}

==> pmml-model-1.0.13-sources.jar: org/dmg/pmml/UnivariateStats.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Counts" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}NumericInfo" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}DiscrStats" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}ContStats" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Anova" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="field" type="{http://www.dmg.org/PMML-4_1}FIELD-NAME" />
 *       &lt;attribute name="weighted" default="0">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;enumeration value="0"/>
 *             &lt;enumeration value="1"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "counts",
    "numericInfo",
    "discrStats",
    "contStats",
    "anova"
})
@XmlRootElement(name = "UnivariateStats")
public class UnivariateStats
    extends PMMLObject
    implements Locatable
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "Counts")
    protected Counts counts;
    @XmlElement(name = "NumericInfo")
    protected NumericInfo numericInfo;
    @XmlElement(name = "DiscrStats")
    protected DiscrStats discrStats;
    @XmlElement(name = "ContStats")
    protected ContStats contStats;
    @XmlElement(name = "Anova")
    protected Anova anova;
    @XmlAttribute(name = "field")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected FieldName field;
    @XmlAttribute(name = "weighted")
    protected String weighted;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the counts property.
     * 
     * @return
     *     possible object is
     *     {@link Counts }
     *     
     */
    public Counts getCounts() {
        return counts;
    }

    /**
     * Sets the value of the counts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Counts }
     *     
     */
    public void setCounts(Counts value) {
        this.counts = value;
    }

    /**
     * Gets the value of the numericInfo property.
     * 
     * @return
     *     possible object is
     *     {@link NumericInfo }
     *     
     */
    public NumericInfo getNumericInfo() {
        return numericInfo;
    }

    /**
     * Sets the value of the numericInfo property.
     * 
     * @param value
     *     allowed object is
     *     {@link NumericInfo }
     *     
     */
    public void setNumericInfo(NumericInfo value) {
        this.numericInfo = value;
    }

    /**
     * Gets the value of the discrStats property.
     * 
     * @return
     *     possible object is
     *     {@link DiscrStats }
     *     
     */
    public DiscrStats getDiscrStats() {
        return discrStats;
    }

    /**
     * Sets the value of the discrStats property.
     * 
     * @param value
     *     allowed object is
     *     {@link DiscrStats }
     *     
     */
    public void setDiscrStats(DiscrStats value) {
        this.discrStats = value;
    }

    /**
     * Gets the value of the contStats property.
     * 
     * @return
     *     possible object is
     *     {@link ContStats }
     *     
     */
    public ContStats getContStats() {
        return contStats;
    }

    /**
     * Sets the value of the contStats property.
     * 
     * @param value
     *     allowed object is
     *     {@link ContStats }
     *     
     */
    public void setContStats(ContStats value) {
        this.contStats = value;
    }

    /**
     * Gets the value of the anova property.
     * 
     * @return
     *     possible object is
     *     {@link Anova }
     *     
     */
    public Anova getAnova() {
        return anova;
    }

    /**
     * Sets the value of the anova property.
     * 
     * @param value
     *     allowed object is
     *     {@link Anova }
     *     
     */
    public void setAnova(Anova value) {
        this.anova = value;
    }

    /**
     * Gets the value of the field property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public FieldName getField() {
        return field;
    }

    /**
     * Sets the value of the field property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setField(FieldName value) {
        this.field = value;
    }

    /**
     * Gets the value of the weighted property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWeighted() {
        if (weighted == null) {
            return "0";
        } else {
            return weighted;
        }
    }

    /**
     * Sets the value of the weighted property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWeighted(String value) {
        this.weighted = value;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

}
